@@ -50,7 +50,6 @@ static Context Ctx;
 
 Context::Context ()
 {
-	g_type_init (); // we need it as we use a static instance which might be created before the others needing gobject types
 	cairo_surface_t *s = cairo_pdf_surface_create ("/tmp/foo", 100., 100.);
 	cairo_t *cr = cairo_create (s);
 	cairo_surface_destroy (s);
@@ -843,6 +842,12 @@ void Text::DeleteTextTag (TextTag *tag, bool rebuild_attributes)
 		RebuildAttributes ();
 }
 
+void Text::ClearTags ()
+{
+	m_Tags.clear ();
+	RebuildAttributes ();
+}
+
 void Text::SetCurTagList (TextTagList *l)
 {
 	if (m_CurTags)
@@ -1661,4 +1666,13 @@ void Text::SetJustification (GtkJustification justification, bool emit_changed)
 	}
 }
 
+double Text::GetMaxLineHeight ()
+{
+	double res = 0.;
+	for (unsigned i = 0; i < m_LinesNumber; i++)
+		if (m_Lines[i].m_Height > res)
+			res = m_Lines[i].m_Height;
+	return res;
+}
+
 }
